/*

DESCRIPTION:  include file for usart.c.

SYNTAX:  n/a

KNOWN BUGS:  n/a.

COPYRIGHT:  (c) 2017, Brian Cornell, all rights reserved.

DEPENDENCIES:  none

VERSION:  2.0, release

MODIFICATION HISTORY:

    15 Oct 19, BWC, added usartWrite function declaration.

    25 Sep 19, BWC, updated pins to use for PIC16F1769 and validated baud rate
    configuration for 115.2Kbps.

    4 Apr 19, BWC, removed _XTAL_FREQ definition. 
    Defined buffer termination character USARTKEYNL for new line

    19 Apr 17, BWC, updated to stay in sync with model 2.0 code that includes 
                    optional flow control.

    5 apr 17, BWC, released v1.0.

    7 Dec 16, BWC, created file.

*/


/*++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
 * Rx & Tx pins:  user must define the pins to use and also the pin configuration
 * bits.
 * 
 * Flow control:  define pins if flow control is to be used.  If not both pin
 * constants MUST be commented out.  Subsequent pin configuration bits are ignored.
 *++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++*/
//#define USART_PINCTS    ???             //Pin to use for CTS
//#define USART_PINRTS    ???             //Pin to use for RTS
#define USART_PINRX     RA0             //Pin to use for Rx
#define USART_PINTX     RA1             //Pin to use for Tx

/*++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
 * Pin configuration:  assign pin configuration register bits corresponding to
 * pin mapping.  Comment out analog select (ANSxx) if not applicable.
 *++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++*/
//#define USART_ANSCTS    ?           //Analog select for CTS pin
//#define USART_TRISCTS   ?          //TRIS control for CTS pin
//#define USART_WPUCTS    ?           //Must be defined if PIC has weak pull-ups enabled
#define USART_ANSRX     ANSA0           //Analog select for Rx pin
#define USART_TRISRX    TRISA0          //TRIS control for Rx pin
#define USART_WPURX     WPUA0           //Must be defined if PIC has weak pull-ups enabled
#define USART_ANSTX     ANSA1           //Analog select for Tx pin
#define USART_TRISTX    TRISA1          //TRIS control for Tx pin
#define USART_SLRTX     SLRA1           //Slew rate for Tx pin
//#define USART_ANSRTS    ?           //Analog select for RTS pin
//#define USART_TRISRTS   ?          //TRIS control for RTS pin
//#define USART_SLRRTS    ?           //Slew rate for RTS pin

/*++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
 * Peripheral Pin Select (PPS) for Rx & Tx pins:  set these as required by the 
 * PIC in use and user pin selections.  Comment out if not required
 *++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++*/
//Rx PPS
#define USART_PPSPRX    RXPPS           //PPS register for Rx
#define USART_PPSVRX    0x00            //Register value mapping pin to USART Rx (RA0)
//Tx PPS
#define USART_PPSPTX    RA1PPS          //Pin to assign to Tx
#define USART_PPSVTX    0x16            //Register value mapping pin to USART Tx

/*++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
 * CTS Interrupt On Change (IOC):  if HW flow control is used then these must
 * be defined to set the respective port register bits and mask.  Necessary to
 * use function usartTxBkgd.
 *++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++*/
//#define USART_IOCREG    ?           //IOC flag register that CTS pin maps to
//#define USART_IOCNEG    ?           //IOC negative edge register that CTS pin maps to
//#define USART_IOCMSK    ?            //IOC bit mask for CTS pin


/*++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
 * USART configuration:  user must set baud rate and TX1 register.
 *++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++*/
#define USART_BRG16     TRUE            //TRUE or FALSE for use of 16-bit baud rate generator
#define USART_BRGH      0x00            //Baud rate high register
#define USART_BRGL      0x22            //Baud rate low register (115.2)
#define USART_TX1STA    0x24            //Register TX1 configuration

/*++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
 * USART & Rx / Tx constants:  these control the behavior of routines and can be 
 * adjusted to suit needs.
 *++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++*/
#define USARTSZRXBUF    64              //Size of receive buffer
#define USARTMXRXBUF    (USARTSZRXBUF - 4)  //Maximum useable size of receive buffer
#define USARTDISDLY     9               //# mS to delay before disabling serial port
#define USARTENADLY     2               //# uS to delay before enabling serial port
#define USARTTXTO       35              //Tx timeout value in uS:  USARTTXWAIT x USARTTXDLY
#define USARTTXWAIT     10              //# uS between Tx retries


/*++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
 *              DO NOT CHANGE ANYTHING BELOW THIS COMMENT.
 *++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++*/
//USART module status codes
#define USARTSTSRXRCV   0x01            //Receive in progress (implies enabled)
#define USARTSTSRXRDY   0x02            //Buffer has NULL terminated line ready for read (implies disabled)
#define USARTSTSRXDIS   0x04            //Buffer is empty and Rx is disabled
#define USARTSTSRXENA   0x08            //Buffer is empty and Rx is enabled
#define USARTSTSRXINT   0x80            //Not initialized
#define USARTSTSTXRDY   0x01            //Tx ready to send
#define USARTSTSTXCTS   0x02            //Tx not ready - CTS set
#define USARTSTSTXBSY   0x04            //Tx not ready - buffer full
#define USARTSTSTXINT   0x80            //Not initialized

//Keyboard codes
#define USARTKEYBS      0x08            //Backspace
#define USARTKEYCR      0x0D            //Carriage return
#define USARTKEYNL      0x0A            //New line

//Macro for echoing received byte during data entry
#define USARTECHO()     if (TXIF && RxEcho) TX1REG = RxByte


//Function declarations.  See source file for explanation of each function.
void usartISR(void);
void usartSetRx(unsigned char);
unsigned char usartStatRx(void);
void usartSetEcho(unsigned char);
unsigned char usartStatTx(void);
unsigned char * usartGetRx(void);
unsigned char usartTxBkgd(unsigned char *, unsigned char);
uint8_t usartWrite(void *, uint8_t);



//End of file